@@ -1,3 +1,6 @@
+#[macro_use]
+extern crate bart_derive;
+
 extern crate clap;
 
 mod arguments;
